@@ -169,8 +169,8 @@ class mkrunner(object):
 
         if USE_ALLURE:
                 import json
-                allure.attach(json.dumps(parsed_request_dict), "request", allure.attachment_type.JSON)
-                allure.attach(json.dumps(resp.json()), "response", allure.attachment_type.JSON)
+                allure.attach(json.dumps(parsed_request_dict, ensure_ascii=False), "request", allure.attachment_type.JSON)
+                allure.attach(json.dumps(resp.json(),ensure_ascii=False), "response", allure.attachment_type.JSON)
 
         # teardown hooks
         if step.teardown_hooks:
